/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.modular.ai.dailyInspection.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;
import vip.xiaonuo.auth.core.util.StpLoginUserUtil;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.modular.ai.dailyInspection.entity.DailyInspection;
import vip.xiaonuo.modular.ai.dailyInspection.entity.vo.DailyInspectionImageVo;
import vip.xiaonuo.modular.ai.dailyInspection.entity.vo.DailyInspectionPageVo;
import vip.xiaonuo.modular.ai.dailyInspection.mapper.DailyInspectionMapper;
import vip.xiaonuo.modular.ai.dailyInspection.param.DailyInspectionEditParam;
import vip.xiaonuo.modular.ai.dailyInspection.param.DailyInspectionIdParam;
import vip.xiaonuo.modular.ai.dailyInspection.param.DailyInspectionPageParam;
import vip.xiaonuo.modular.ai.dailyInspection.service.DailyInspectionService;
import vip.xiaonuo.modular.bi.utils.UploadImage;

import javax.validation.constraints.NotBlank;
import java.io.IOException;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.List;

/**
 * 日常巡检Service接口实现类
 *
 * @author newspaper
 * @date  2024/01/08 15:58
 **/
@Service
public class DailyInspectionServiceImpl extends ServiceImpl<DailyInspectionMapper, DailyInspection> implements DailyInspectionService {

    @Autowired
    private DailyInspectionMapper dailyInspectionMapper;
    @Autowired
    private UploadImage uploadImage;

    @Override
    public Page<DailyInspectionImageVo> page(DailyInspectionPageParam dailyInspectionPageParam) {
        Integer status = dailyInspectionPageParam.getStatus();
        String userId = StpLoginUserUtil.getLoginUser().getId();
        Integer orgId = dailyInspectionPageParam.getOrgId();
        Page<DailyInspectionPageVo> page = dailyInspectionMapper.page(CommonPageRequest.defaultPage(), userId, status, orgId);
        Page<DailyInspectionImageVo> dailyInspectionImageVoPage = new Page<>();
        List dailyInspectionImageVoList = new ArrayList<>();
        for (DailyInspectionPageVo record : page.getRecords()) {
            DailyInspectionImageVo dailyInspectionImageVo = new DailyInspectionImageVo();
            BeanUtil.copyProperties(record,dailyInspectionImageVo);
            if (ObjectUtil.isNotEmpty(record.getImgUrl())){
                dailyInspectionImageVo.setPages(record.getImgUrl().split(","));
            }
            dailyInspectionImageVoList.add(dailyInspectionImageVo);
        }
        dailyInspectionImageVoPage.setRecords(dailyInspectionImageVoList);
        dailyInspectionImageVoPage.setTotal(page.getTotal());
        dailyInspectionImageVoPage.setCountId(page.getCountId());
        dailyInspectionImageVoPage.setCurrent(page.getCurrent());
        return dailyInspectionImageVoPage;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(String id, String inspectTime, String inspectPersonId, String description, MultipartFile img1, MultipartFile img2, MultipartFile img3) throws IOException {
        DailyInspection dailyInspection = this.getById(id);
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy:MM:dd HH:mm:ss");
        dailyInspection.setInspectTime(LocalDateTime.parse(inspectTime,formatter));
        dailyInspection.setInspectPersonId(inspectPersonId);
        dailyInspection.setDescription(description);
        String imgUrl = "";
        if (ObjectUtil.isNotEmpty(img1)){
            if (!uploadImage.getImageCom(img1).equals("上传失败")){
                imgUrl = uploadImage.getImageCom(img1);
            }
        }
        if (ObjectUtil.isNotEmpty(img2)){
            if (!uploadImage.getImageCom(img2).equals("上传失败")){
                imgUrl = imgUrl + "," + uploadImage.getImageCom(img2);
            }
        }
        if (ObjectUtil.isNotEmpty(img3)){
            if (!uploadImage.getImageCom(img3).equals("上传失败")){
                imgUrl = imgUrl + "," + uploadImage.getImageCom(img3);
            }
        }
        dailyInspection.setImgUrl(imgUrl);
        dailyInspection.setStatus(1);
        this.updateById(dailyInspection);
    }

    @Override
    public DailyInspectionImageVo detail(DailyInspectionIdParam dailyInspectionIdParam) {
        String id = dailyInspectionIdParam.getId();
        DailyInspectionImageVo dailyInspectionImageVo = new DailyInspectionImageVo();
        DailyInspectionPageVo dailyInspectionPageVo = dailyInspectionMapper.detail(id);
        BeanUtil.copyProperties(dailyInspectionPageVo,dailyInspectionImageVo);
        if (ObjectUtil.isNotEmpty(dailyInspectionPageVo.getImgUrl())){
            dailyInspectionImageVo.setPages(dailyInspectionPageVo.getImgUrl().split(","));
        }
        return dailyInspectionImageVo;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<DailyInspectionIdParam> dailyInspectionIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(dailyInspectionIdParamList, DailyInspectionIdParam::getId));
    }


}
